==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-kbindicator/translations/kbindicator_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="49"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>Písanie veľkými písmenami (CapsLock)</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="53"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="55"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>Uzamknutie číselnej klávesnice (NumLock)</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="60"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="62"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>Zamknúť posúvanie obrazu (ScrollLock)</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Layout</source>
        <translation>Rozvrhnutie</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Nastavenie stavu klávesnice</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Indikovať zámky</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Ukazovať CapsLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Ukazovať NumLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Ukazovať ScrollLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Ukazovať rozloženie klávesnice</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Pravidlo pre prepínanie</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="99"/>
        <source>Flags path pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="106"/>
        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="116"/>
        <source>Configure layouts</source>
        <translation>Nastaviť rozloženie</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Globálne</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Aplikácie</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.0.1.tar.xz: lxqt-panel-2.0.1/plugin-kbindicator/translations/kbindicator_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="49"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>Písanie veľkými písmenami (CapsLock)</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="53"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="55"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>Uzamknutie číselnej klávesnice (NumLock)</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="60"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="62"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>Zamknúť posúvanie obrazu (ScrollLock)</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Layout</source>
        <translation>Rozvrhnutie</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Nastavenie stavu klávesnice</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Indikovať zámky</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Ukazovať CapsLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Ukazovať NumLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Ukazovať ScrollLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Ukazovať rozloženie klávesnice</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Pravidlo pre prepínanie</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="99"/>
        <source>Flags path pattern:</source>
        <translation>Vzor cesty k vlajke:</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="106"/>
        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
        <translation>Vzor cesty súboru pre vlajky krajín. Musí obsahovať &lt;strong&gt;%1&lt;/strong&gt;, nahradené dvoma písmenami ISO kódu krajiny (malé písmená).&lt;br&gt;&lt;br&gt;Príklad: /usr/share/iso-flags-svg/country-squared/%1.svg</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="116"/>
        <source>Configure layouts</source>
        <translation>Nastaviť rozloženie</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Globálne</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Aplikácie</translation>
    </message>
</context>
</TS>
